/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsIInterfaceRequest">
 **/

package org.mozilla.xpcom;

public interface nsIInterfaceRequestor extends nsISupports
{
  public static final String NS_IINTERFACEREQUESTOR_IID =
    "{033a1470-8b2a-11d3-af88-00a024ffc08c}";

  public nsISupports getInterface(String arg1);

}
